<?php
require_once __DIR__ . '/inc/spider.php';
$config = require __DIR__ . '/config.php';
require_once __DIR__ . '/inc/database.php';
require_once __DIR__ . '/inc/function.php';


// 处理广告显示
$adstype = isset($config['adstype']) ? $config['adstype'] : (isset($_GET['adstype']) ? intval($_GET['adstype']) : 0);
handleAdDisplay($adstype);

// 获取主机信息
$host = strtolower($_SERVER['HTTP_HOST'] ?? '');
$mainDomain = (function($host) {
    $parts = explode('.', $host);
    $c = count($parts);
    return $c >= 2 ? $parts[$c-2].'.'.$parts[$c-1] : $host;
})($host);

// 获取请求URI
$uri = strtok($_SERVER['REQUEST_URI'] ?? '/', '?');
$uri = rtrim($uri, '/');
$template_dir = rtrim($config['template_dir'], '/\\') . DIRECTORY_SEPARATOR;

// 缓存文件路径设置
$cacheBaseDir = rtrim($config['cache_dir'], '/\\') . DIRECTORY_SEPARATOR;
$mainDomainHash = substr(md5($mainDomain), 0, 10);
$hostHash = substr(md5($host), 0, 10);
$cacheDir = $cacheBaseDir . $mainDomainHash . DIRECTORY_SEPARATOR . $hostHash . DIRECTORY_SEPARATOR;

// 确保缓存目录存在
if (!is_dir($cacheDir)) {
    if (!mkdir($cacheDir, 0777, true)) {
        error_log("无法创建缓存目录：{$cacheDir}");
    } else {
        chmod($cacheDir, 0777); 
    }
}

$cacheHash = substr(md5($host . $uri), 0, 10);
$cacheFile = $cacheDir . $cacheHash . '.html';

$cache_ttl = 7 * 24 * 3600; 

// 检查文件缓存是否有效
if (file_exists($cacheFile) && (time() - filemtime($cacheFile) < $cache_ttl)) {
    echo file_get_contents($cacheFile);
    exit;
}

$prefixes_pattern = get_random_domain($_SERVER['HTTP_HOST'] );


$rootPaths = ['', '/index.php', '/index.html'];
if (preg_match('/\.(css|js|jpg|jpeg|png|gif|ico|svg|woff|woff2|ttf|eot|mp4|webp)$/i', $uri)) return false;
if ($uri === '/sitemap.xml') {
    include __DIR__ . '/config/sitemap.php';
    exit;
}

// 随机选择一个模板文件
$template_files = glob($template_dir . '*.html');
if (!$template_files) exit('未找到模板文件');
$tpl = basename($template_files[array_rand($template_files)]);

$template_file = $template_dir . $tpl;
$pdo = DBCache::initPDO();
if (!$pdo) {
    exit('数据库连接失败');
}

$pdo->setAttribute(PDO::ATTR_DEFAULT_FETCH_MODE, PDO::FETCH_ASSOC);
$template = file_get_contents($template_file);

$webname = null;

//{当前域名}
$scheme = (!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] !== 'off') ? 'https' : 'http';
$host = $_SERVER['HTTP_HOST'] ?? '';
$template = str_replace(['{当前域名}','{当前域名}'], $scheme . '://' .$host, $template);

//{当前链接}
$request_uri = $_SERVER['REQUEST_URI'] ?? '';
$current_url = $scheme . '://' . $host . $request_uri;
$template = str_replace(['{当前链接}','｛当前链接｝'], $current_url, $template);

//{模板路径}
$root_dir = rtrim(dirname(__FILE__), '/\\') ;
$template_relative_path = str_replace($root_dir, '', str_replace('\\', '/', $config['template_dir']));
$template = str_replace(['{模板路径}', '｛模板路径｝'], $template_relative_path, $template);

//{随机图片}
$random_img_path = '';
$img_dir = rtrim(str_replace('\\','/',$config['template_dir']),'/') . '/static/picture';
if (is_dir($img_dir)) {
    $img_files = glob($img_dir . '/*.{jpg,jpeg,png,gif,webp,JPG,JPEG,PNG,GIF,WEBP}', GLOB_BRACE);
    if ($img_files && count($img_files) > 0) {
        $random_img = $img_files[array_rand($img_files)];
 
        $root_dir = rtrim(str_replace('\\','/',dirname(__FILE__)), '/');
        $random_img_path = str_replace($root_dir . '/', '', str_replace('\\','/', $random_img));
    }
}

//{日期}
$now_date = date('Y-m-d');
$template = str_replace(['{日期}','｛日期｝'], $now_date, $template);

//{字符}
$rand_str = substr(str_shuffle('ABCDEFGHJKLMNPQRSTUVWXYZabcdefghijkmnpqrstuvwxyz23456789'), 0, 8);
$template = str_replace(['{字符}','｛字符｝'], $rand_str, $template);

//{数字}
$rand_num = str_pad(mt_rand(100, 999), 3, '0', STR_PAD_LEFT);
$template = str_replace(['{数字}','｛数字｝'], $rand_num, $template);

//{微信}
$wx = $config['wx'] ?? '';
$template = str_replace(['{微信}','｛微信｝'], $wx, $template);

//{qq}
$qq = $config['qq'] ?? '';
$template = str_replace(['{qq}','｛qq｝'], $qq, $template);

//{电话}
$tel = $config['tel'] ?? '';
$template = str_replace(['{电话}','｛电话｝'], $tel, $template);

//{地址}
$addr = $config['addr'] ?? '';
$template = str_replace(['{地址}','｛地址｝'], $addr, $template);

$template = str_replace(['{随机图片}', '｛随机图片｝'], '/' . ltrim($random_img_path, '/'), $template);

// {分页N} 
if (preg_match_all('/\{分页(\d+)\}/u', $template, $page_matches)) {
    require_once __DIR__ . '/inc/page.php';
    foreach ($page_matches[1] as $idx => $n) {
        $pagination_html = render_pagination_html((int)$n);
        $template = str_replace($page_matches[0][$idx], $pagination_html, $template);
    }
}


// {导航N}
if (preg_match_all('/\{导航(\d+)\}/u', $template, $nav_matches)) {
    require_once __DIR__ . '/inc/nav.php';
    foreach ($nav_matches[1] as $idx => $n) {
        $nav_html = render_nav([], intval($n)); // 由 nav.php 内部决定内容和样式
        $template = str_replace($nav_matches[0][$idx], $nav_html, $template);
    }
}


// {文章列表N} OK
if (preg_match_all('/\{文章列表(\d+)\}/u', $template, $matches)) {
    require_once __DIR__ . '/inc/list.php';
    $page = isset($_GET['page']) ? max(1, intval($_GET['page'])) : 1;
    $page_size = 10;
    
    // 直接处理每个文章列表标记
    foreach ($matches[1] as $idx => $n) {
        // 每种样式直接调用article_list获取不同数据
        $style = intval($n);
        $article_html = article_list($style, $page_size);
        
        // 直接替换模板中的标记
        $template = str_replace($matches[0][$idx], $article_html, $template);
    }
}

// 将处理后的模板赋值给$html
$html = $template;


// {title} 标签 - 组合格式：随机关键词+随机标题
if (preg_match_all('/\{title\}/u', $html, $title_matches)) {
    require_once __DIR__ . '/inc/function.php';
    
    foreach ($title_matches[0] as $match) {
        
        $random_keyword = get_keywords(1);

        $random_title = get_titles(1);

        $combined_title = $random_keyword . ' ' . $random_title;

        $html = str_replace($match, unicode16($combined_title), $html);
    }
}

// {keywordsN} 

if (preg_match_all('/\{keywords(\d+)\}/u', $html, $matches)) {
    foreach ($matches[1] as $idx => $n) {
        $random_keywords = get_keywords($n);
        $html = str_replace($matches[0][$idx], unicode16($random_keywords), $html);
    }
}

require_once __DIR__ . '/config/tags.php';

// 确保$article_id变量已定义
$article_id = isset($article_id) ? $article_id : null;

// 获取标签配置
$tags = get_tags_config($pdo, $host, $article_id);

// 预处理所有标签替换
$replacements = [];
    foreach ($tags as $k => $v) {
        $value = is_callable($v) ? $v() : $v;
        // 确保值是字符串
        $replacements['{' . $k . '}'] = is_array($value) ? implode(',', $value) : (string)$value;
    }
    

$html = str_replace(array_keys($replacements), array_values($replacements), $html);


echo $html;

    file_put_contents($cacheFile, $html);
